conway_polynomials: Python interface to Frank Lübeck's Conway polynomial database
=================================================================================

Description
-----------

This python module evolved from the old SageMath *conway_polynomials*
package once hosted at,

  http://files.sagemath.org/spkg/upstream/conway_polynomials/

It's still maintained by Sage developers, but having a pip-installable
interface to the data will make it easier to install SageMath via pip
or another package manager.


License
-------

GPL version 3 or later


Upstream Contact
----------------

https://github.com/sagemath/conway-polynomials
